@@ -2,6 +2,7 @@
 
 from .cache import ClassificationCache, VisionCache
 from .engine import ClassificationEngine
+from .exceptions import LLMResponseError, LLMUnavailableError
 from .models import (
     ClassificationBatch,
     ClassificationDecision,
@@ -19,4 +20,6 @@ __all__ = [
     "ClassificationRequest",
     "VisionCaption",
     "VisionCaptioner",
+    "LLMUnavailableError",
+    "LLMResponseError",
 ]
