@@ -3,4 +3,4 @@
 import os
 
 # Enable heuristic classifier for the test suite unless explicitly overridden.
-os.environ.setdefault("DORGY_USE_FALLBACK", "1")
+os.environ.setdefault("DORGY_USE_FALLBACKS", "1")
